@@ -138,3 +138,39 @@ class DSHelper(BaseSqlHelper):
 
     def sync_execute_fetchall(self, sql: str, param=None):
         return self.db_helper.sync_execute_fetchall(sql, param)
+
+    def sync_connect(self, database: str = None, table: str = None):
+        if self.conn_info.dialect == "postgresql":
+            return self.pool
+        elif self.conn_info.dialect == "mysql":
+            return self.pool
+        elif self.conn_info.dialect == "mongodb":
+            collection = self.pool[database][table]
+            return collection
+        elif self.conn_info.dialect == "elasticsearch":
+            return self.pool
+        elif self.conn_info.dialect == "esapi":
+            return self.pool
+        elif self.conn_info.dialect == "redis":
+            connect = self.pool.get_connection(sync=True)
+            return connect
+        else:
+            return Exception(f"connect type ({self.conn_info.dialect}) is not supported")
+
+    async def connect(self, database: str = None, table: str = None):
+        if self.conn_info.dialect == "postgresql":
+            return self.pool
+        elif self.conn_info.dialect == "mysql":
+            return self.pool
+        elif self.conn_info.dialect == "mongodb":
+            collection = self.pool[database][table]
+            return collection
+        elif self.conn_info.dialect == "elasticsearch":
+            return self.pool
+        elif self.conn_info.dialect == "esapi":
+            return self.pool
+        elif self.conn_info.dialect == "redis":
+            connect = self.pool.get_connection()
+            return connect
+        else:
+            return Exception(f"connect type ({self.conn_info.dialect}) is not supported")
