@@ -396,3 +396,27 @@ class EsHelper:
             "data_list": data_list
         }
         return result
+
+    def sync_es_mapping(self, route_key, field: str = None):
+        path = f"/{route_key}/_mapping"
+        if field:
+            path = f"{path}/field/{field}"
+        url = self.pool.format_url(path)
+        res = self.pool.format_es_get(url)
+        return res
+
+    def sync_es_request(self, path, method, params=None, body=None):
+        url = self.pool.format_url(path)
+        if method in ["get", "post", "put", "delete"]:
+            res = None
+            if method == "get":
+                res = self.pool.format_es_get(url, params)
+            elif method == "post":
+                res = self.pool.format_es_post(url, body, params)
+            elif method == "put":
+                res = self.pool.format_es_put(url, body, params)
+            elif method == "delete":
+                res = self.pool.format_es_delete(url, body, params)
+            return res
+        else:
+            raise Exception(f"method={method} is not supported")
