@@ -41,9 +41,10 @@ class EsRequest:
                 continue
         return res
 
-    def format_es_post(self, url, body):
+    def format_es_post(self, url, body, params=None):
         """
         发送http请求
+        :param params:
         :param url:
         :param body:
         :return:
@@ -52,6 +53,7 @@ class EsRequest:
             url,
             data=json.dumps(body),
             headers={'content-type': "application/json"},
+            params=params,
             auth=self.auth
         )
         res = r.json()
