@@ -27,12 +27,12 @@ class Ks3Oss:
         bucket = self.client.create_bucket(bucket_name=bucket_name, **kwargs)
         return bucket
 
-    def list_buckets(self):
-        buckets = self.client.get_all_buckets()
+    def list_buckets(self, **kwargs):
+        buckets = self.client.get_all_buckets(**kwargs)
         return [b.name for b in buckets]
 
-    def delete_bucket(self, bucket_name):
-        return self.client.delete_bucket(bucket_name)
+    def delete_bucket(self, bucket_name, **kwargs):
+        return self.client.delete_bucket(bucket_name, **kwargs)
 
     def save(self, key, bucket_name="", content_type="string", protocol="https", domain="ksyun.com",
              region="ks3-cn-beijing", **kwargs):
@@ -56,41 +56,41 @@ class Ks3Oss:
         else:
             return False
 
-    def get_url(self, key, bucket_name="", region="ks3-cn-beijing", domain="ksyun.com", protocol="https"):
+    def get_url(self, key, bucket_name="", region="ks3-cn-beijing", domain="ksyun.com", protocol="https", **kwargs):
         if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
-        if self.instance.get_key(key):
+        if self.instance.get_key(key, **kwargs):
             return f'{protocol}://{bucket_name}.{region}.{domain}/{key}'
         else:
             return None
 
-    def get_file(self, key, bucket_name="", file_path=None):
+    def get_file(self, key, bucket_name="", file_path=None, **kwargs):
         if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         k = self.instance.get_key(key)
         if file_path:
-            k.get_contents_to_filename(file_path)
+            k.get_contents_to_filename(file_path, **kwargs)
             return True
         else:
-            contents = k.get_contents_as_string().decode()
+            contents = k.get_contents_as_string(**kwargs)
             return contents
 
-    def get_key(self, key, bucket_name=""):
+    def get_key(self, key, bucket_name="", **kwargs):
         if bucket_name:
-            self.instance = self.client.get_bucket(bucket_name)
+            self.instance = self.client.get_bucket(bucket_name, **kwargs)
         k = self.instance.get_key(key)
         return k
 
-    def delete_file(self, key, bucket_name=None):
+    def delete_file(self, key, bucket_name=None, **kwargs):
         if bucket_name:
-            self.instance = self.client.get_bucket(bucket_name)
+            self.instance = self.client.get_bucket(bucket_name, **kwargs)
         res = self.instance.delete_key(key)
         return res
 
-    def list_file(self, bucket_name, delimiter="/"):
+    def list_file(self, bucket_name, delimiter="/", **kwargs):
         if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
-        keys = self.instance.list(delimiter=delimiter)
+        keys = self.instance.list(delimiter=delimiter, **kwargs)
         files = list()
         dirs = list()
         for k in keys:
@@ -100,7 +100,7 @@ class Ks3Oss:
                 dirs.append(k.name)
 
         for p in dirs:
-            keys = self.instance.list(prefix=p)
+            keys = self.instance.list(prefix=p, delimiter=delimiter, **kwargs)
             for k in keys:
                 if isinstance(k, Key):
                     files.append(k.name)
@@ -108,10 +108,10 @@ class Ks3Oss:
                     dirs.append(k.name)
         return dirs, files
 
-    def get_bucket_acl(self, bucket_name=None):
+    def get_bucket_acl(self, bucket_name=None, **kwargs):
         if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
-        acl = self.instance.get_acl()
+        acl = self.instance.get_acl(**kwargs)
         return acl
 
     def set_bucket_acl(self, bucket_name=None, *args, **kwargs):
@@ -119,10 +119,10 @@ class Ks3Oss:
             self.instance = self.client.get_bucket(bucket_name)
         return self.instance.set_acl(*args, **kwargs)
 
-    def get_bucket_policy(self, bucket_name=None):
+    def get_bucket_policy(self, bucket_name=None, **kwargs):
         if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
-        policy = self.instance.get_bucket_policy()
+        policy = self.instance.get_bucket_policy(**kwargs)
         return policy
 
     def set_bucket_policy(self, policy, bucket_name=None, headers=None):
@@ -160,22 +160,24 @@ class Ks3Oss:
             self.instance = self.client.get_bucket(bucket_name)
         return self.instance.list_multipart_uploads(key, **kwargs)
 
-    def generate_url(self, key, second, bucket_name=None):
+    def generate_url(self, key, bucket_name=None, **kwargs):
         if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
-        k = self.instance.get_key(key)
+        key_kwargs = kwargs.get("key_kwargs", {})
+        url_kwargs = kwargs.get("url_kwargs", {})
+        k = self.instance.get_key(key, **key_kwargs)
         if k:
-            url = k.generate_url(second)
+            url = k.generate_url(**url_kwargs)
             return url
         else:
             return None
 
-    def get_presigned_url(self, key, second, bucket_name=None, expires_in_absolute=False):
+    def get_presigned_url(self, key, second, bucket_name=None, expires_in_absolute=False, **kwargs):
         if bucket_name:
             self.instance = self.client.get_bucket(bucket_name)
         k = self.instance.new_key(key)
         if k:
-            url = k.get_presigned_url(second, expires_in_absolute=expires_in_absolute)
+            url = k.get_presigned_url(second=second, expires_in_absolute=expires_in_absolute, **kwargs)
             return url
         else:
             return None
