@@ -28,7 +28,8 @@ define("application_name", default=f"{os.path.split(os.path.dirname(sys.argv[0])
 define("project_name", default=f"{os.path.split(os.path.dirname(sys.argv[0]))[-1]}", type=str, help="配置文件")
 define("application_path", default=f"{os.path.abspath(os.path.dirname(sys.argv[0]))}", type=str, help="应用运行根路径")
 define("cookie_secret", default="hRHQlJoUQIiNai2MLV9fQV3YDpxWrUHQp/jnfF9riQk=", type=str, help="cookie 秘钥 ")
-define("static_path", default=os.path.join(f"{os.path.dirname(sys.argv[0])}", "static"), type=str, help="静态资源目录")
+define("static_path", default=os.path.join(f"{os.path.abspath(os.path.dirname(sys.argv[0]))}", "static"), type=str,
+       help="静态资源目录")
 define("aes_key", default="haohaoxuexi", type=str, help="aes加密key")
 define("data_server", default="http://127.0.0.1:8901", type=str, help="数据服务")
 define("profile", default="profiles.config", type=str, help="配置文件")
